import * as i0 from '@angular/core';
import { inject, signal, input, effect, computed, Component, ViewEncapsulation, ViewContainerRef, Directive } from '@angular/core';
import { I18NEXT_NAMESPACE, I18NextCapPipe } from 'angular-i18next';
import { tap, combineLatest, startWith } from 'rxjs';
import { FormControlName } from '@angular/forms';

class ValidationMessage {
    key;
    params;
    constructor(key = '', params) {
        this.key = key;
        this.params = params;
    }
}

class I18NextValidationMessageComponent {
    i18nextNamespace = inject(I18NEXT_NAMESPACE);
    validationString = 'validation';
    manualSettedFor = signal(null);
    messages = signal([]);
    controlChangesSub = null;
    for = input(null);
    setFor(control) {
        this.manualSettedFor.set(control);
    }
    constructor() {
        effect(() => {
            this.controlChangesSub?.unsubscribe();
            this.messages.set([]);
            const control = this.control();
            if (!control?.valueChanges) {
                return;
            }
            control.statusChanges?.pipe(tap((s) => console.log(s))).subscribe();
            this.controlChangesSub = combineLatest([control.valueChanges, control.statusChanges]).pipe(startWith([control.value, control.status]), tap(() => {
                this.messages.set(this.getErrorMessages(control));
            })).subscribe();
        });
    }
    control = computed(() => this.for() ?? this.manualSettedFor());
    firstMessage = computed(() => this.messages()[0] ?? new ValidationMessage());
    controlPath = computed(() => this.control()?.path?.join('.') ?? '');
    i18nextKey = computed(() => {
        if (!this.firstMessage().key)
            return '';
        const specificKey = [
            this.validationString,
            ['control_specific', this.controlPath(), this.firstMessage().key].join('.')
        ].join(':');
        const commonKey = [this.validationString, this.firstMessage().key].join(':');
        const i18nextKeys = [];
        if (this.i18nextNamespace && this.i18nextNamespace !== this.validationString) {
            i18nextKeys.push([this.i18nextNamespace, specificKey].join('.'));
            i18nextKeys.push([this.i18nextNamespace, commonKey].join('.'));
        }
        i18nextKeys.push(specificKey);
        i18nextKeys.push(commonKey);
        return i18nextKeys;
    });
    getErrorMessages(control) {
        const errors = control.errors;
        if (!errors)
            return [];
        return Object.entries(errors ?? {}).map(([key, value]) => {
            let params = null;
            if (value instanceof Object) {
                params = value;
            }
            else if (value !== true) {
                params = { [key]: value };
            }
            return new ValidationMessage(key, params);
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.7", ngImport: i0, type: I18NextValidationMessageComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "19.1.7", type: I18NextValidationMessageComponent, isStandalone: true, selector: "i18next-validation-message", inputs: { for: { classPropertyName: "for", publicName: "for", isSignal: true, isRequired: false, transformFunction: null } }, host: { classAttribute: "i18next-validation-message" }, ngImport: i0, template: `
    <div class="error-container">{{ i18nextKey() | i18nextCap: firstMessage().params }}</div>
    <i class="error-icon"></i>
  `, isInline: true, styles: [".i18next-validation-message{display:none;width:100%;position:relative}.i18next-validation-message.standalone,.ng-dirty.ng-invalid+.i18next-validation-message{display:block}\n"], dependencies: [{ kind: "pipe", type: I18NextCapPipe, name: "i18nextCap" }], encapsulation: i0.ViewEncapsulation.None });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.7", ngImport: i0, type: I18NextValidationMessageComponent, decorators: [{
            type: Component,
            args: [{ selector: 'i18next-validation-message', template: `
    <div class="error-container">{{ i18nextKey() | i18nextCap: firstMessage().params }}</div>
    <i class="error-icon"></i>
  `, encapsulation: ViewEncapsulation.None, standalone: true, imports: [I18NextCapPipe], host: {
                        'class': 'i18next-validation-message'
                    }, styles: [".i18next-validation-message{display:none;width:100%;position:relative}.i18next-validation-message.standalone,.ng-dirty.ng-invalid+.i18next-validation-message{display:block}\n"] }]
        }], ctorParameters: () => [] });

class I18NextValidationMessageDirective {
    viewContainer = inject(ViewContainerRef);
    formControlName = inject(FormControlName, { optional: true });
    validationMessageComponent = null;
    ngAfterViewInit() {
        this.detach();
        this.validationMessageComponent = this.viewContainer.createComponent(I18NextValidationMessageComponent);
        const control = this.formControlName;
        this.validationMessageComponent.instance.setFor(control);
        this.validationMessageComponent.changeDetectorRef.detectChanges();
    }
    ngOnDestroy() {
        this.detach();
    }
    detach() {
        if (this.validationMessageComponent?.changeDetectorRef) {
            this.validationMessageComponent.changeDetectorRef.detach();
            this.validationMessageComponent = null;
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.7", ngImport: i0, type: I18NextValidationMessageDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.1.7", type: I18NextValidationMessageDirective, isStandalone: true, selector: "[formControlName][i18nextValidationMessage],[formGroupName][i18nextValidationMessage],[formArrayName][i18nextValidationMessage]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.7", ngImport: i0, type: I18NextValidationMessageDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[formControlName][i18nextValidationMessage],[formGroupName][i18nextValidationMessage],[formArrayName][i18nextValidationMessage]',
                    standalone: true
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { I18NextValidationMessageComponent, I18NextValidationMessageDirective, ValidationMessage };
//# sourceMappingURL=angular-i18next-forms.mjs.map
