import { EnvironmentProviders, Type } from '@angular/core';
import { I18NextErrorHandlingStrategy } from './I18NextErrorHandlingStrategies';
import { I18NextFeature, I18NextFeatureKind } from './provider.utils';
export declare function localeIdFactory(): string;
/**
 * Provides the necessary dependencies for using i18next with Angular.
 *
 * @param features An array of features to enable. See {@link I18NextFeature} for available features.
 * @returns An array of providers that can be added to the root providers.
 *
 * @example
 * import { provideI18Next } from '@angular-i18next/core';
 *
 *   providers: [
 *     provideI18Next(),
 *   ],
 *
 */
export declare function provideI18Next(...features: I18NextFeature<I18NextFeatureKind>[]): EnvironmentProviders;
/**
 * Configures a custom error handling strategy for i18next.
 *
 * @param errorHandlingStrategy - A class implementing the I18NextErrorHandlingStrategy interface.
 * @returns An I18NextFeature for the specified custom error handling strategy.
 *
 * This feature allows the integration of a custom error handling mechanism
 * into the i18next setup, replacing the default error handling strategy.
 *
 *  * Example:
 * ```typescript
 *    providers: [
 *       provideI18Next(withCustomErrorHandlingStrategy(StrictErrorHandlingStrategy)())
 *    ]
 * ```
 */
export declare function withCustomErrorHandlingStrategy(errorHandlingStrategy: Type<I18NextErrorHandlingStrategy>): I18NextFeature<I18NextFeatureKind.CustomErrorHandlingStrategy>;
/**
 * Provides I18NextTitle service for document title translation support.
 *
 * @returns An I18NextFeature that configures the I18NextTitle service
 *
 * Example:
 * ```typescript
 * providers: [
 *   provideI18Next(withTitle())
 * ]
 * ```
 */
export declare function withTitle(): I18NextFeature<I18NextFeatureKind.Title>;
